@@ -66,14 +66,14 @@ sub cmd_stop {
             qq{The stop time you specified (%s) is earlier than the start time (%s).\nThis makes no sense.},
             $task->stop, $task->start );
 
-        my $what_you_ment = $task->stop->clone;
+        my $what_you_meant = $task->stop->clone;
         for ( 1 .. 5 ) {
-            $what_you_ment->add( days => 1 );
-            last if $what_you_ment > $task->start;
+            $what_you_meant->add( days => 1 );
+            last if $what_you_meant > $task->start;
         }
-        if ( $what_you_ment ne $task->start ) {
+        if ( $what_you_meant ne $task->start ) {
             say "Maybe you wanted to do:\ntracker stop --at '"
-                . $what_you_ment->strftime('%Y-%m-%d %H:%M') . "'";
+                . $what_you_meant->strftime('%Y-%m-%d %H:%M') . "'";
         }
         else {
             say
@@ -207,7 +207,7 @@ sub cmd_list {
             : ()
         ),
     );
-my $total=0;
+    my $total=0;
     foreach my $file (@files) {
         my $task = App::TimeTracker::Data::Task->load( $file->stringify );
         my $time = $task->seconds // $task->_build_seconds;
@@ -455,6 +455,8 @@ sub cmd_commands {
         push( @commands, $method );
     }
 
+    @commands = sort @commands;
+
     if (   $self->can('autocomplete')
         && $self->autocomplete )
     {
@@ -640,7 +642,7 @@ App::TimeTracker::Command::Core - App::TimeTracker Core commands
 
 =head1 VERSION
 
-version 3.002
+version 3.003
 
 =head1 CORE COMMANDS
 
@@ -763,11 +765,11 @@ some projects.
 
 =head4 --from TT::DateTime [REQUIRED (or use --this/--last)]
 
-Begin of reporting iterval, defaults to first day of current month.
+Begin of reporting interval, defaults to first day of current month.
 
 =head4 --to TT::DateTime [REQUIRED (or use --this/--last)]
 
-End of reporting iterval, default to DateTime->now.
+End of reporting interval, default to DateTime->now.
 
 =head4 --this [day, week, month, year]
 
@@ -855,7 +857,7 @@ List all installed plugins (i.e. stuff in C<App::TimeTracker::Command::*>)
     ~/perl/Your-Project$ tracker recalc_trackfile --trackfile 20110808-232327_App_TimeTracker.trc
 
 Recalculates the duration stored in an old trackfile. Might be useful
-after a manual update in a trackfile. Might be unneccessary in the
+after a manual update in a trackfile. Might be unnecessary in the
 future, as soon as task duration is always calculated lazily.
 
 =head3 Options:
@@ -880,7 +882,7 @@ Thomas Klausner <domm@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2019 by Thomas Klausner.
+This software is copyright (c) 2011 - 2020 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
